package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.PointsTransaction;

/**
 * 积分流水Service接口
 *
 * @author ruoyi
 * @date 2025-05-30
 */
public interface IPointsTransactionService extends IService<PointsTransaction>
{
    /**
     * 查询积分流水
     *
     * @param id 积分流水主键
     * @return 积分流水
     */
    public PointsTransaction selectPointsTransactionById(Long id);

    /**
     * 查询积分流水列表
     *
     * @param pointsTransaction 积分流水
     * @return 积分流水集合
     */
    public List<PointsTransaction> selectPointsTransactionList(PointsTransaction pointsTransaction);

    /**
     * 新增积分流水
     *
     * @param pointsTransaction 积分流水
     * @return 结果
     */
    public int insertPointsTransaction(PointsTransaction pointsTransaction);

    /**
     * 修改积分流水
     *
     * @param pointsTransaction 积分流水
     * @return 结果
     */
    public int updatePointsTransaction(PointsTransaction pointsTransaction);

    /**
     * 批量删除积分流水
     *
     * @param ids 需要删除的积分流水主键集合
     * @return 结果
     */
    public int deletePointsTransactionByIds(Long[] ids);

    /**
     * 删除积分流水信息
     *
     * @param id 积分流水主键
     * @return 结果
     */
    public int deletePointsTransactionById(Long id);
}
