package com.ruoyi.web.controller.system;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PointsTransaction;
import com.ruoyi.system.service.IPointsTransactionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分流水Controller
 *
 * @author ruoyi
 * @date 2025-05-30
 */
@RestController
@RequestMapping("/system/pointTransaction")
public class PointTransactionController extends BaseController
{
    @Autowired
    private IPointsTransactionService pointsTransactionService;

    /**
     * 查询积分流水列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:list')")
    @GetMapping("/list")
    public TableDataInfo list(PointsTransaction pointsTransaction)
    {
        startPage();
        List<PointsTransaction> list = pointsTransactionService.selectPointsTransactionList(pointsTransaction);
        return getDataTable(list);
    }

    /**
     * 导出积分流水列表
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:export')")
    @Log(title = "积分流水", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PointsTransaction pointsTransaction)
    {
        List<PointsTransaction> list = pointsTransactionService.selectPointsTransactionList(pointsTransaction);
        ExcelUtil<PointsTransaction> util = new ExcelUtil<PointsTransaction>(PointsTransaction.class);
        util.exportExcel(response, list, "积分流水数据");
    }

    /**
     * 获取积分流水详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pointsTransactionService.selectPointsTransactionById(id));
    }

    /**
     * 新增积分流水
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:add')")
    @Log(title = "积分流水", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PointsTransaction pointsTransaction)
    {
        return toAjax(pointsTransactionService.insertPointsTransaction(pointsTransaction));
    }

    /**
     * 修改积分流水
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:edit')")
    @Log(title = "积分流水", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PointsTransaction pointsTransaction)
    {
        return toAjax(pointsTransactionService.updatePointsTransaction(pointsTransaction));
    }

    /**
     * 删除积分流水
     */
    @PreAuthorize("@ss.hasPermi('system:pointTransaction:remove')")
    @Log(title = "积分流水", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pointsTransactionService.deletePointsTransactionByIds(ids));
    }
}

